import { LitElement, TemplateResult } from 'lit-element';
/**
 * A LitElement wrapper of the scroll directive.
 *
 * Import this module to declare the lit-virtualizer custom element.
 * Pass an items array, renderItem method, and scroll target as properties
 * to the <lit-virtualizer> element.
 */
export declare class LitVirtualizer<T> extends LitElement {
    private _renderItem;
    items: Array<T>;
    scrollTarget: Element | Window;
    private _scrollToIndex;
    constructor();
    /**
     * The method used for rendering each item.
     */
    renderItem: (item: T, index?: number) => TemplateResult;
    /**
     * Scroll to the specified index, placing that item at the given position
     * in the scroll view.
     */
    scrollToIndex(index: number, position?: string): Promise<void>;
    render(): TemplateResult;
}
declare global {
    interface HTMLElementTagNameMap {
        'lit-virtualizer': LitVirtualizer<unknown>;
    }
}
//# sourceMappingURL=lit-virtualizer.d.ts.map