import { VirtualRepeater } from './VirtualRepeater.js';
import { Layout } from './layouts/Layout.js';
export declare class RangeChangeEvent extends Event {
    private _first;
    private _last;
    private _firstVisible;
    private _lastVisible;
    constructor(type: any, init: any);
    readonly first: number;
    readonly last: number;
    readonly firstVisible: number;
    readonly lastVisible: number;
}
interface VirtualScrollerConfig {
    layout: Layout;
    /**
     * An element that receives scroll events for the virtual scroller.
     */
    scrollTarget: Element | Window;
    /**
     * Whether to build the virtual scroller within a shadow DOM.
     */
    useShadowDOM: boolean;
    /**
     * The parent of all child nodes to be rendered.
     */
    container: Element | ShadowRoot;
}
/**
 * Provides virtual scrolling boilerplate.
 *
 * Extensions of this class must set container, layout, scrollTarget, and
 * useShadowDOM.
 *
 * Extensions of this class must also override VirtualRepeater's DOM
 * manipulation methods.
 */
export declare class VirtualScroller<Item, Child extends HTMLElement, Key> extends VirtualRepeater<Item, Child, Key> {
    /**
     * Whether the layout should receive an updated viewport size on the next
     * render.
     */
    private _needsUpdateView;
    private _layout;
    /**
     * Whether to import the default (1d) layout on first render.
     */
    private _lazyLoadDefaultLayout;
    /**
     * The element that generates scroll events and defines the container
     * viewport. Set by scrollTarget.
     */
    private _scrollTarget;
    /**
     * A sentinel element that sizes the container when it is a scrolling
     * element. This ensures the scroll bar accurately reflects the total
     * size of the list.
     */
    private _sizer;
    /**
     * Layout provides these values, we set them on _render().
     * TODO @straversi: Can we find an XOR type, usable for the key here?
     */
    private _scrollSize;
    /**
     * Difference between scroll target's current and required scroll offsets.
     * Provided by layout.
     */
    private _scrollErr;
    /**
     * A list of the positions (top, left) of the children in the current range.
     */
    private _childrenPos;
    /**
     * The parent of all child nodes to be rendered. Set by container.
     */
    private _containerElement;
    /**
     * Keep track of original inline style of the container, so it can be
     * restored when container is changed.
     */
    private _containerInlineStyle;
    /**
     * Keep track of original container stylesheet, so it can be restored
     * when container is changed.
     */
    private _containerStylesheet;
    /**
     * Whether to build the virtual scroller within a shadow DOM.
     */
    private _useShadowDOM;
    /**
     * Size of the container.
     */
    private _containerSize;
    /**
     * Resize observer attached to container.
     */
    private _containerRO;
    /**
     * Resize observer attached to children.
     */
    private _childrenRO;
    /**
     * Flag for skipping a children measurement if that computation was just
     * completed.
     */
    private _skipNextChildrenSizeChanged;
    /**
     * Index and position of item to scroll to.
     */
    private _scrollToIndex;
    /**
     * Index of the first item intersecting the container element.
     */
    private _firstVisible;
    /**
     * Index of the last item intersecting the container element.
     */
    private _lastVisible;
    constructor(config: VirtualScrollerConfig);
    container: Element | ShadowRoot;
    layout: Layout;
    /**
     * The element that generates scroll events and defines the container
     * viewport. The value `null` (default) corresponds to `window` as scroll
     * target.
     */
    scrollTarget: Element | Window | null;
    useShadowDOM: boolean;
    /**
     * Index and position of item to scroll to. The scroller will fix to that point
     * until the user scrolls.
     */
    scrollToIndex: {
        index: number;
        position?: string;
    };
    /**
     * Display the items in the current range.
     * Continue relayout of child positions until they have stabilized.
     */
    protected _render(): Promise<void>;
    /**
     * Position children before they get measured. Measuring will force relayout,
     * so by positioning them first, we reduce computations.
     */
    _didRender(): void;
    handleEvent(event: any): void;
    private _initResizeObservers;
    private _applyContainerStyles;
    private _createContainerSizer;
    /**
     * TODO: Rename _ordered to _kids?
     */
    readonly _kids: Array<Child>;
    /**
     * Render and update the view at the next opportunity.
     */
    private _scheduleUpdateView;
    private _updateView;
    /**
     * Styles the _sizer element or the container so that its size reflects the
     * total size of all items.
     */
    private _sizeContainer;
    /**
     * Sets the top and left transform style of the children from the values in
     * pos.
     */
    private _positionChildren;
    private _adjustRange;
    protected _shouldRender(): boolean;
    private _correctScrollError;
    /**
     * Emits a rangechange event with the current first, last, firstVisible, and
     * lastVisible.
     */
    private _notifyRange;
    /**
     * Render and update the view at the next opportunity with the given
     * container size.
     */
    private _containerSizeChanged;
    private _childrenSizeChanged;
}
export {};
//# sourceMappingURL=VirtualScroller.d.ts.map